TOOL_GUIDELINES = """# Tool Use Guidelines

1. In <thinking> tags, first review your Sutra Memory to understand current task status, completed work, and previous tool results to avoid redundancy. Then assess what information you already have and what information you need to proceed with the task. Consider pending tasks and current task requirements - if you identify information that will be needed in future iterations but not used in the current iteration, store it directly in Sutra Memory to avoid redundant tool calls later. Data of current iteration won't be available in the next iterations - only stored data in sutra memory is persistent across iterations.
2. Choose the most appropriate tool based on the task and the tool descriptions provided. Assess if you need additional information to proceed, and which of the available tools would be most effective for gathering this information. For example using the search_keyword tool is more effective than running a command like `grep` in the terminal. It's critical that you think about each available tool and use the one that best fits the current step in the task. Check your Sutra Memory history to see if similar tool calls have been attempted previously.
3. For terminal commands, implement smart session management:
   - Check existing sessions first using `list_sessions` action before creating new ones
   - Reuse compatible sessions for similar task types when available
   - Use generic descriptions like "Build process", "Testing", "File operations" (not task-specific)
   - Use `close_after=true` for one-off commands that don't need session persistence
   - Clean up sessions when task sequences are complete to maintain system efficiency
4. If multiple actions are needed, use one tool at a time per message to accomplish the task iteratively, with each tool use being informed by the result of the previous tool use. Do not assume the outcome of any tool use. Each step must be informed by the previous step's result and tracked in your Sutra Memory.
5. Formulate your tool use using the XML format specified for each tool.
6. After each tool use, the user will respond with the result of that tool use. This result will provide you with the necessary information to continue your task or make further decisions. This response may include:
  - Information about whether the tool succeeded or failed, along with any reasons for failure.
  - Linter errors that may have arisen due to the changes you made, which you'll need to address.
  - New terminal output in reaction to the changes, which you may need to consider or act upon.
  - Any other relevant feedback or information related to the tool use.
7. ALWAYS wait for user confirmation after each tool use before proceeding. Never assume the success of a tool use without explicit confirmation of the result from the user.
8. After receiving tool results, ALWAYS update your Sutra Memory with:
   - A history entry summarizing the tool use and its results
   - Any important code findings stored for future reference using XML format with proper file paths, line numbers, and descriptions
   - Task status updates (moving from pending to current to completed)
   - New tasks discovered during the analysis
   - Remove stored code when no longer needed

It is crucial to proceed step-by-step, waiting for the user's message after each tool use before moving forward with the task. This approach allows you to:
1. Confirm the success of each step before proceeding.
2. Address any issues or errors that arise immediately.
3. Adapt your approach based on new information or unexpected results.
4. Ensure that each action builds correctly on the previous ones.
5. Maintain accurate Sutra Memory tracking of your progress and findings.

By waiting for and carefully considering the user's response after each tool use, you can react accordingly and make informed decisions about how to proceed with the task. This iterative process helps ensure the overall success and accuracy of your work while maintaining comprehensive memory tracking.

"""
